datastructuretools.Digraph
==========================

.. abjad-lineage:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph

.. autoclass:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.child_graph
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.cyclic_nodes
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.edges
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.is_cyclic
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.nodes
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.parent_graph
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.root_nodes
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.storage_format
   :noindex:

.. autoattribute:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.terminal_nodes
   :noindex:

Methods
-------

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.partition
   :noindex:

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.reverse
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__eq__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__ge__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__gt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__le__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__lt__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__ne__
   :noindex:

.. automethod:: abjad.tools.datastructuretools.Digraph.Digraph.Digraph.__repr__
   :noindex:
